.. _contact:

Contact Us
==========

This project is developed and maintained by the `ODISSEI Social Data Science (SoDa) <https://odissei-data.nl/nl/soda/>`_ team and the `FIRMBACKBONE <https://firmbackbone.nl/>`_ Project.

.. image:: https://avatars.githubusercontent.com/u/71822308?s=200&v=4
   :alt: SoDa logo
   :width: 200px
   :align: center

Do you have questions, suggestions, or remarks? File an issue in the `issue tracker <https://github.com/sodascience/websweep/issues/>`_ or feel free to contact the team of `ODISSEI Social Data Science <https://odissei-data.nl/en/using-soda/>`_.
